/*
 * Icon configuration file for generic POSIX system with X windows
 */

#define UNIX 1
#define LoadFunc

